export declare enum KMX_Version {
    VERSION_30 = 768,
    VERSION_31 = 769,
    VERSION_32 = 770,
    VERSION_40 = 1024,
    VERSION_50 = 1280,
    VERSION_501 = 1281,
    VERSION_60 = 1536,
    VERSION_70 = 1792,
    VERSION_80 = 2048,
    VERSION_90 = 2304,
    VERSION_100 = 2560,
    VERSION_140 = 3584,
    VERSION_150 = 3840,
    VERSION_160 = 4096,
    VERSION_170 = 4352
}
export declare class KEYBOARD {
    fileVersion?: number;
    startGroup: {
        ansi: number;
        unicode: number;
        newContext: number;
        postKeystroke: number;
    };
    flags?: number;
    hotkey?: number;
    groups: GROUP[];
    stores: STORE[];
    keyboardVersion?: string;
    isMnemonic: boolean;
    targets: string;
}
export declare class STORE {
    dwSystemID: number;
    dpName: string;
    dpString: string;
}
export declare class GROUP {
    dpName: string;
    keys: KEY[];
    dpMatch: string;
    dpNoMatch: string;
    fUsingKeys: boolean;
}
export declare class KEY {
    Key: number;
    Line: number;
    ShiftFlags: number;
    dpOutput: string;
    dpContext: string;
}
export interface BUILDER_COMP_KEYBOARD {
    dwIdentifier: number;
    dwFileVersion: number;
    dwCheckSum: number;
    KeyboardID: number;
    IsRegistered: number;
    version: number;
    cxStoreArray: number;
    cxGroupArray: number;
    dpStoreArray: number;
    dpGroupArray: number;
    StartGroup_ANSI: number;
    StartGroup_Unicode: number;
    dwFlags: number;
    dwHotKey: number;
    dpBitmapOffset: number;
    dwBitmapSize: number;
}
export interface BUILDER_COMP_KEYBOARD_KMXPLUSINFO {
    dpKMXPlus: number;
    dwKMXPlusSize: number;
}
export interface BUILDER_COMP_STORE {
    dwSystemID: number;
    dpName: number;
    dpString: number;
}
export interface BUILDER_COMP_KEY {
    Key: number;
    _padding: number;
    Line: number;
    ShiftFlags: number;
    dpOutput: number;
    dpContext: number;
}
export interface BUILDER_COMP_GROUP {
    dpName: number;
    dpKeyArray: number;
    dpMatch: number;
    dpNoMatch: number;
    cxKeyArray: number;
    fUsingKeys: number;
}
export declare class KMXFile {
    readonly COMP_STORE: any;
    readonly COMP_KEY: any;
    readonly COMP_GROUP: any;
    readonly COMP_KEYBOARD_KMXPLUSINFO: any;
    readonly COMP_KEYBOARD: any;
    static readonly FILEID_COMPILED = 1398036555;
    static readonly VERSION_30 = KMX_Version.VERSION_30;
    static readonly VERSION_31 = KMX_Version.VERSION_31;
    static readonly VERSION_32 = KMX_Version.VERSION_32;
    static readonly VERSION_40 = KMX_Version.VERSION_40;
    static readonly VERSION_50 = KMX_Version.VERSION_50;
    static readonly VERSION_501 = KMX_Version.VERSION_501;
    static readonly VERSION_60 = KMX_Version.VERSION_60;
    static readonly VERSION_70 = KMX_Version.VERSION_70;
    static readonly VERSION_80 = KMX_Version.VERSION_80;
    static readonly VERSION_90 = KMX_Version.VERSION_90;
    static readonly VERSION_100 = KMX_Version.VERSION_100;
    static readonly VERSION_140 = KMX_Version.VERSION_140;
    static readonly VERSION_150 = KMX_Version.VERSION_150;
    static readonly VERSION_160 = KMX_Version.VERSION_160;
    static readonly VERSION_170 = KMX_Version.VERSION_170;
    static readonly VERSION_MIN = KMX_Version.VERSION_50;
    static readonly VERSION_MAX = KMX_Version.VERSION_170;
    static readonly BK_DEFAULT = 0;
    static readonly BK_DEADKEY = 1;
    static readonly BEGIN_ANSI = 0;
    static readonly BEGIN_UNICODE = 1;
    static readonly TSS_NONE = 0;
    static readonly TSS_BITMAP = 1;
    static readonly TSS_COPYRIGHT = 2;
    static readonly TSS_HOTKEY = 3;
    static readonly TSS_LANGUAGE = 4;
    static readonly TSS_LAYOUT = 5;
    static readonly TSS_MESSAGE = 6;
    static readonly TSS_NAME = 7;
    static readonly TSS_VERSION = 8;
    static readonly TSS_CAPSONONLY = 9;
    static readonly TSS_CAPSALWAYSOFF = 10;
    static readonly TSS_SHIFTFREESCAPS = 11;
    static readonly TSS_LANGUAGENAME = 12;
    static readonly TSS_CALLDEFINITION = 13;
    static readonly TSS_CALLDEFINITION_LOADFAILED = 14;
    static readonly TSS_ETHNOLOGUECODE = 15;
    static readonly TSS_DEBUG_LINE = 16;
    static readonly TSS_MNEMONIC = 17;
    static readonly TSS_INCLUDECODES = 18;
    static readonly TSS_OLDCHARPOSMATCHING = 19;
    static readonly TSS_COMPILEDVERSION = 20;
    static readonly TSS_KEYMANCOPYRIGHT = 21;
    static readonly TSS_CUSTOMKEYMANEDITION = 22;
    static readonly TSS_CUSTOMKEYMANEDITIONNAME = 23;
    static readonly TSS__KEYMAN_60_MAX = 23;
    static readonly TSS_VISUALKEYBOARD = 24;
    static readonly TSS_KMW_RTL = 25;
    static readonly TSS_KMW_HELPFILE = 26;
    static readonly TSS_KMW_HELPTEXT = 27;
    static readonly TSS_KMW_EMBEDJS = 28;
    static readonly TSS_WINDOWSLANGUAGES = 29;
    static readonly TSS__KEYMAN_70_MAX = 29;
    static readonly TSS_COMPARISON = 30;
    static readonly TSS__KEYMAN_80_MAX = 30;
    static readonly TSS_PLATFORM = 31;
    static readonly TSS_BASELAYOUT = 32;
    static readonly TSS_LAYER = 33;
    static readonly TSS_PLATFORM_NOMATCH = 32769;
    static readonly TSS_PLATFORM_MATCH = 32770;
    static readonly TSS_VKDICTIONARY = 34;
    static readonly TSS_LAYOUTFILE = 35;
    static readonly TSS_KEYBOARDVERSION = 36;
    static readonly TSS_KMW_EMBEDCSS = 37;
    static readonly TSS_TARGETS = 38;
    static readonly TSS__KEYMAN_90_MAX = 38;
    static readonly TSS_CASEDKEYS = 39;
    static readonly TSS__KEYMAN_140_MAX = 39;
    static readonly TSS_BEGIN_NEWCONTEXT = 40;
    static readonly TSS_BEGIN_POSTKEYSTROKE = 41;
    static readonly TSS_NEWLAYER = 42;
    static readonly TSS_OLDLAYER = 43;
    static readonly TSS__KEYMAN_150_MAX = 43;
    static readonly TSS_DISPLAYMAP = 44;
    static readonly TSS__KEYMAN_170_MAX = 44;
    static readonly TSS__MAX = 44;
    static readonly UC_SENTINEL = 65535;
    static readonly UC_SENTINEL_EXTENDEDEND = 16;
    static readonly U_UC_SENTINEL = "\uFFFF";
    static readonly VK__MAX = 255;
    static readonly CODE_ANY = 1;
    static readonly CODE_INDEX = 2;
    static readonly CODE_CONTEXT = 3;
    static readonly CODE_NUL = 4;
    static readonly CODE_USE = 5;
    static readonly CODE_RETURN = 6;
    static readonly CODE_BEEP = 7;
    static readonly CODE_DEADKEY = 8;
    static readonly CODE_EXTENDED = 10;
    static readonly CODE_SWITCH = 12;
    static readonly CODE_KEY = 13;
    static readonly CODE_CLEARCONTEXT = 14;
    static readonly CODE_CALL = 15;
    static readonly CODE_CONTEXTEX = 17;
    static readonly CODE_NOTANY = 18;
    static readonly CODE_KEYMAN70_LASTCODE = 18;
    static readonly CODE_SETOPT = 19;
    static readonly CODE_IFOPT = 20;
    static readonly CODE_SAVEOPT = 21;
    static readonly CODE_RESETOPT = 22;
    static readonly CODE_KEYMAN80_LASTCODE = 22;
    static readonly CODE_IFSYSTEMSTORE = 23;
    static readonly CODE_SETSYSTEMSTORE = 24;
    static readonly CODE_LASTCODE = 24;
    static readonly KF_SHIFTFREESCAPS = 1;
    static readonly KF_CAPSONONLY = 2;
    static readonly KF_CAPSALWAYSOFF = 4;
    static readonly KF_LOGICALLAYOUT = 8;
    static readonly KF_AUTOMATICVERSION = 16;
    static readonly KF_KMXPLUS = 32;
    static readonly HK_ALT = 65536;
    static readonly HK_CTRL = 131072;
    static readonly HK_SHIFT = 262144;
    static readonly LCTRLFLAG: number;
    static readonly RCTRLFLAG: number;
    static readonly LALTFLAG: number;
    static readonly RALTFLAG: number;
    static readonly K_SHIFTFLAG: number;
    static readonly K_CTRLFLAG: number;
    static readonly K_ALTFLAG: number;
    static readonly CAPITALFLAG: number;
    static readonly NOTCAPITALFLAG: number;
    static readonly NUMLOCKFLAG: number;
    static readonly NOTNUMLOCKFLAG: number;
    static readonly SCROLLFLAG: number;
    static readonly NOTSCROLLFLAG: number;
    static readonly ISVIRTUALKEY: number;
    static readonly VIRTUALCHARKEY: number;
    static readonly MASK_MODIFIER_CHIRAL: number;
    static readonly MASK_MODIFIER_SHIFT: number;
    static readonly MASK_MODIFIER_NONCHIRAL: number;
    static readonly MASK_STATEKEY: number;
    static readonly MASK_KEYTYPE: number;
    static readonly MASK_MODIFIER: number;
    static readonly MASK_KEYS: number;
    static readonly KMX_MASK_VALID: number;
    static readonly K_MODIFIERFLAG = 127;
    static readonly K_NOTMODIFIERFLAG = 65280;
    static readonly COMP_KEYBOARD_SIZE = 64;
    static readonly COMP_KEYBOARD_KMXPLUSINFO_SIZE = 8;
    static readonly COMP_STORE_SIZE = 12;
    static readonly COMP_GROUP_SIZE = 24;
    static readonly COMP_KEY_SIZE = 20;
    static readonly VERSION_MASK_MINOR = 255;
    static readonly VERSION_MASK_MAJOR = 65280;
    keyboard: KEYBOARD;
    constructor();
}
//# sourceMappingURL=kmx.d.ts.map