//
// Visual Keyboard in-memory data
//
// Corresponds to .kvk / .kvks file data
//
/**
 * The default font and size are not very important, as generally they are
 * unused, because font information is provided in the package, but we include
 * them for completeness. The size is included as a negative value which is
 * defined in the LOGFONT structure in Windows API.
 */
export const DEFAULT_KVK_FONT = {
    name: "Arial",
    size: -12
};
export class VisualKeyboard {
    header = { flags: 0, ansiFont: {}, unicodeFont: {}, underlyingLayout: undefined };
    keys = [];
}
;
export { BUILDER_KVK_HEADER_FLAGS as VisualKeyboardHeaderFlags } from "./kvk-file.js";
export class VisualKeyboardHeader {
    version; // 0x0600
    flags;
    associatedKeyboard;
    ansiFont; // generally unused
    unicodeFont;
    underlyingLayout;
}
;
export class VisualKeyboardFont {
    name;
    size;
}
;
export { BUILDER_KVK_KEY_FLAGS as VisualKeyboardKeyFlags } from "./kvk-file.js";
export { BUILDER_KVK_SHIFT_STATE as VisualKeyboardShiftState } from "./kvk-file.js";
export class VisualKeyboardKey {
    flags;
    shift;
    vkey;
    text;
    bitmap; // .bmp, unsupported in ldml keyboards; included for round-tripabilty
}
;
;
import { USVirtualKeyCodes as vk } from "../consts/virtual-key-constants.js";
export const VisualKeyboardLegalShiftStates = [
    { desc: 'Unshifted', name: '', shift: 0 /* ss.KVKS_NORMAL */, vkeys: [] }, //1
    { desc: 'Shift', name: 'S', shift: 1 /* ss.KVKS_SHIFT */, vkeys: [vk.K_SHIFT] },
    { desc: 'Ctrl', name: 'C', shift: 2 /* ss.KVKS_CTRL */, vkeys: [vk.K_CONTROL] },
    { desc: 'Alt', name: 'A', shift: 4 /* ss.KVKS_ALT */, vkeys: [vk.K_ALT] },
    { desc: 'Shift+Ctrl', name: 'SC', shift: 1 /* ss.KVKS_SHIFT */ | 2 /* ss.KVKS_CTRL */, vkeys: [vk.K_SHIFT, vk.K_CONTROL] },
    { desc: 'Shift+Alt', name: 'SA', shift: 1 /* ss.KVKS_SHIFT */ | 4 /* ss.KVKS_ALT */, vkeys: [vk.K_SHIFT, vk.K_ALT] },
    { desc: 'Ctrl+Alt', name: 'CA', shift: 2 /* ss.KVKS_CTRL */ | 4 /* ss.KVKS_ALT */, vkeys: [vk.K_CONTROL, vk.K_ALT] },
    { desc: 'Shift+Ctrl+Alt', name: 'SCA', shift: 1 /* ss.KVKS_SHIFT */ | 2 /* ss.KVKS_CTRL */ | 4 /* ss.KVKS_ALT */, vkeys: [vk.K_SHIFT, vk.K_CONTROL, vk.K_ALT] }, //7
    { desc: 'Left Ctrl', name: 'LC', shift: 8 /* ss.KVKS_LCTRL */, vkeys: [vk.K_LCONTROL] },
    { desc: 'Right Ctrl', name: 'RC', shift: 16 /* ss.KVKS_RCTRL */, vkeys: [vk.K_RCONTROL] },
    { desc: 'Left Alt', name: 'LA', shift: 32 /* ss.KVKS_LALT */, vkeys: [vk.K_LALT] },
    { desc: 'Right Alt', name: 'RA', shift: 64 /* ss.KVKS_RALT */, vkeys: [vk.K_RALT] },
    { desc: 'Shift+Left Ctrl', name: 'SLC', shift: 1 /* ss.KVKS_SHIFT */ | 8 /* ss.KVKS_LCTRL */, vkeys: [vk.K_SHIFT, vk.K_LCONTROL] },
    { desc: 'Shift+Right Ctrl', name: 'SRC', shift: 1 /* ss.KVKS_SHIFT */ | 16 /* ss.KVKS_RCTRL */, vkeys: [vk.K_SHIFT, vk.K_RCONTROL] },
    { desc: 'Shift+Left Alt', name: 'SLA', shift: 1 /* ss.KVKS_SHIFT */ | 32 /* ss.KVKS_LALT */, vkeys: [vk.K_SHIFT, vk.K_LALT] },
    { desc: 'Shift+Right Alt', name: 'SRA', shift: 1 /* ss.KVKS_SHIFT */ | 64 /* ss.KVKS_RALT */, vkeys: [vk.K_SHIFT, vk.K_RALT] },
    { desc: 'Left Ctrl+Left Alt', name: 'LCLA', shift: 8 /* ss.KVKS_LCTRL */ | 32 /* ss.KVKS_LALT */, vkeys: [vk.K_LCONTROL, vk.K_LALT] },
    { desc: 'Left Ctrl+Right Alt', name: 'LCRA', shift: 8 /* ss.KVKS_LCTRL */ | 64 /* ss.KVKS_RALT */, vkeys: [vk.K_LCONTROL, vk.K_RALT] },
    { desc: 'Right Ctrl+Left Alt', name: 'RCLA', shift: 16 /* ss.KVKS_RCTRL */ | 32 /* ss.KVKS_LALT */, vkeys: [vk.K_RCONTROL, vk.K_LALT] },
    { desc: 'Right Ctrl+Right Alt', name: 'RCRA', shift: 16 /* ss.KVKS_RCTRL */ | 64 /* ss.KVKS_RALT */, vkeys: [vk.K_RCONTROL, vk.K_RALT] },
    { desc: 'Shift+Left Ctrl+Left Alt', name: 'SLCLA', shift: 1 /* ss.KVKS_SHIFT */ | 8 /* ss.KVKS_LCTRL */ | 32 /* ss.KVKS_LALT */, vkeys: [vk.K_SHIFT, vk.K_LCONTROL, vk.K_LALT] },
    { desc: 'Shift+Left Ctrl+Right Alt', name: 'SLCRA', shift: 1 /* ss.KVKS_SHIFT */ | 8 /* ss.KVKS_LCTRL */ | 64 /* ss.KVKS_RALT */, vkeys: [vk.K_SHIFT, vk.K_LCONTROL, vk.K_RALT] },
    { desc: 'Shift+Right Ctrl+Left Alt', name: 'SRCLA', shift: 1 /* ss.KVKS_SHIFT */ | 16 /* ss.KVKS_RCTRL */ | 32 /* ss.KVKS_LALT */, vkeys: [vk.K_SHIFT, vk.K_RCONTROL, vk.K_LALT] },
    { desc: 'Shift+Right Ctrl+Right Alt', name: 'SRCRA', shift: 1 /* ss.KVKS_SHIFT */ | 16 /* ss.KVKS_RCTRL */ | 64 /* ss.KVKS_RALT */, vkeys: [vk.K_SHIFT, vk.K_RCONTROL, vk.K_RALT] }, //16
];
//# sourceMappingURL=visual-keyboard.js.map