declare const _default: {
    $schema: string;
    $ref: string;
    definitions: {
        KeyboardInfo: {
            type: string;
            properties: {
                id: {
                    type: string;
                };
                name: {
                    type: string;
                };
                authorName: {
                    type: string;
                };
                authorEmail: {
                    type: string;
                    format: string;
                };
                description: {
                    type: string;
                };
                license: {
                    type: string;
                    enum: string[];
                };
                languages: {
                    anyOf: ({
                        type: string;
                        items: {
                            type: string;
                        };
                        uniqueItems: boolean;
                        $ref?: undefined;
                    } | {
                        $ref: string;
                        type?: undefined;
                        items?: undefined;
                        uniqueItems?: undefined;
                    })[];
                };
                lastModifiedDate: {
                    type: string;
                    format: string;
                };
                packageFilename: {
                    type: string;
                    pattern: string;
                };
                packageFileSize: {
                    type: string;
                };
                jsFilename: {
                    type: string;
                    pattern: string;
                };
                jsFileSize: {
                    type: string;
                };
                isRTL: {
                    type: string;
                };
                encodings: {
                    type: string;
                    items: {
                        type: string;
                        enum: string[];
                    };
                };
                packageIncludes: {
                    type: string;
                    items: {
                        type: string;
                        enum: string[];
                    };
                };
                version: {
                    type: string;
                };
                minKeymanVersion: {
                    type: string;
                    pattern: string;
                };
                helpLink: {
                    type: string;
                    pattern: string;
                };
                platformSupport: {
                    $ref: string;
                };
                sourcePath: {
                    type: string;
                    pattern: string;
                };
                related: {
                    type: string;
                    patternProperties: {
                        ".": {
                            $ref: string;
                        };
                    };
                    additionalProperties: boolean;
                };
                deprecated: {
                    type: string;
                };
            };
            required: string[];
        };
        KeyboardLanguageInfo: {
            type: string;
            patternProperties: {
                ".": {
                    $ref: string;
                };
            };
            additionalProperties: boolean;
        };
        KeyboardLanguageInfoItem: {
            type: string;
            properties: {
                font: {
                    $ref: string;
                };
                oskFont: {
                    $ref: string;
                };
                examples: {
                    type: string;
                    items: {
                        $ref: string;
                    };
                };
                displayName: {
                    type: string;
                };
                languageName: {
                    type: string;
                };
                scriptName: {
                    type: string;
                };
                regionName: {
                    type: string;
                };
            };
            required: any[];
            additionalProperties: boolean;
        };
        KeyboardFontInfo: {
            type: string;
            properties: {
                family: {
                    type: string;
                };
                source: {
                    type: string;
                    items: {
                        type: string;
                    };
                };
            };
            required: string[];
            additionalProperties: boolean;
        };
        KeyboardExampleInfo: {
            type: string;
            properties: {
                keys: {
                    type: string;
                };
                text: {
                    type: string;
                };
                note: {
                    type: string;
                };
            };
            required: string[];
            additionalProperties: boolean;
        };
        KeyboardPlatformInfo: {
            type: string;
            patternProperties: {
                "^(windows|macos|desktopWeb|ios|android|mobileWeb|linux)$": {
                    type: string;
                    enum: string[];
                };
            };
            required: any[];
            additionalProperties: boolean;
        };
        KeyboardRelatedInfo: {
            type: string;
            properties: {
                deprecates: {
                    type: string;
                };
                deprecatedBy: {
                    type: string;
                };
            };
            required: any[];
            additionalProperties: boolean;
        };
    };
};
export default _default;
//# sourceMappingURL=keyboard_info.schema.d.ts.map