declare const _default: {
    $schema: string;
    $ref: string;
    $comment: string;
    description: string;
    definitions: {
        "touch-layout": {
            type: string;
            properties: {
                tablet: {
                    $ref: string;
                };
                phone: {
                    $ref: string;
                };
                desktop: {
                    $ref: string;
                };
            };
            minProperties: number;
            additionalProperties: boolean;
        };
        platform: {
            type: string;
            properties: {
                font: {
                    $ref: string;
                };
                fontsize: {
                    $ref: string;
                };
                layer: {
                    $ref: string;
                };
                displayUnderlying: {
                    type: string;
                };
                defaultHint: {
                    type: string;
                    enum: string[];
                };
            };
            required: string[];
            additionalProperties: boolean;
        };
        layers: {
            type: string;
            items: {
                $ref: string;
            };
            minItems: number;
        };
        layer: {
            type: string;
            properties: {
                id: {
                    $ref: string;
                };
                row: {
                    $ref: string;
                };
            };
            required: string[];
            additionalProperties: boolean;
        };
        "layer-id": {
            type: string;
            pattern: string;
        };
        rows: {
            type: string;
            items: {
                $ref: string;
            };
            minItems: number;
        };
        row: {
            type: string;
            properties: {
                id: {
                    $ref: string;
                };
                key: {
                    $ref: string;
                };
            };
            required: string[];
            additionalProperties: boolean;
        };
        "row-id": {
            type: string;
            minimum: number;
            maximum: number;
        };
        keys: {
            type: string;
            items: {
                $ref: string;
            };
            minItems: number;
        };
        key: {
            type: string;
            properties: {
                id: {
                    $ref: string;
                };
                text: {
                    type: string;
                };
                layer: {
                    $ref: string;
                };
                nextlayer: {
                    $ref: string;
                };
                font: {
                    $ref: string;
                };
                fontsize: {
                    $ref: string;
                };
                sp: {
                    $ref: string;
                };
                pad: {
                    $ref: string;
                };
                width: {
                    $ref: string;
                };
                sk: {
                    $ref: string;
                };
                flick: {
                    $ref: string;
                };
                multitap: {
                    $ref: string;
                };
                hint: {
                    type: string;
                };
            };
            anyOf: {
                required: string[];
            }[];
            additionalProperties: boolean;
        };
        "key-id": {
            type: string;
            pattern: string;
        };
        "key-sp": {
            type: string;
            enum: number[];
        };
        "key-pad": {
            type: string;
            minimum: number;
            maximum: number;
        };
        "key-width": {
            type: string;
            minimum: number;
            maximum: number;
        };
        subkeys: {
            type: string;
            items: {
                $ref: string;
            };
            minItems: number;
        };
        subkey: {
            type: string;
            properties: {
                id: {
                    $ref: string;
                };
                text: {
                    type: string;
                };
                layer: {
                    $ref: string;
                };
                nextlayer: {
                    $ref: string;
                };
                font: {
                    $ref: string;
                };
                fontsize: {
                    $ref: string;
                };
                sp: {
                    $ref: string;
                };
                pad: {
                    $ref: string;
                };
                width: {
                    $ref: string;
                };
            };
            required: string[];
            additionalProperties: boolean;
        };
        flick: {
            type: string;
            patternProperties: {
                "^(n|s|e|w|ne|nw|se|sw)$": {
                    $ref: string;
                };
            };
            minProperties: number;
            additionalProperties: boolean;
        };
        "font-spec": {
            type: string;
        };
        "fontsize-spec": {
            type: string;
        };
    };
};
export default _default;
//# sourceMappingURL=keyman-touch-layout.clean.spec.d.ts.map