import { constants } from "@keymanapp/ldml-keyboard-constants";
import { KMXPlus } from "@keymanapp/common-types";
import { build_strs_index } from "./build-strs.js";
var StrsItem = KMXPlus.StrsItem;
;
;
;
;
;
export function build_layr(kmxplus, sect_strs, sect_list) {
    if (!kmxplus.layr?.lists) {
        return null; // if there aren't any layers at all (which should be an invalid keyboard)
    }
    const layr = {
        ident: constants.hex_section_id(constants.section.layr),
        size: constants.length_layr,
        _offset: 0,
        listCount: kmxplus.layr.lists.length,
        layerCount: 0, // calculated below
        rowCount: 0, // calculated below
        keyCount: 0, // calculated below
        lists: [],
        layers: [],
        rows: [],
        keys: []
    };
    layr.lists = kmxplus.layr.lists.map((list) => {
        const blist = {
            hardware: build_strs_index(sect_strs, list.hardware),
            layer: null, // to be set below
            _layers: list.layers,
            count: list.layers.length,
            minDeviceWidth: list.minDeviceWidth,
        };
        return blist;
    });
    // now sort the lists
    layr.lists.sort((a, b) => {
        // sort by string #
        if (a.hardware < b.hardware) {
            return -1;
        }
        else if (a.hardware > b.hardware) {
            return 1;
        }
        if (a.minDeviceWidth < b.minDeviceWidth) {
            return -1;
        }
        else if (a.minDeviceWidth > b.minDeviceWidth) {
            return 1;
        }
        else {
            return 0; // same
        }
    });
    // Now allocate the layers, rows, and keys
    layr.lists.forEach((list) => {
        list.layer = layr.layers.length; // index to first layer in list
        const blayers = list._layers.map((layer) => {
            const blayer = {
                _id: layer.id.value, // original id
                id: build_strs_index(sect_strs, layer.id),
                mod: layer.mod,
                row: null, // row ID, to be filled in
                _rows: layer.rows, // temporary
                count: layer.rows.length, // number of rows
            };
            return blayer;
        });
        // sort the new layers
        blayers.sort((a, b) => StrsItem.binaryStringCompare(a._id, b._id));
        blayers.forEach((layer) => {
            layer.row = layr.rows.length; // index to first row in list
            layer._rows.forEach((row) => {
                const brow = {
                    key: layr.keys.length,
                    count: row.keys.length,
                };
                row.keys.forEach((key) => {
                    const bkey = {
                        key: build_strs_index(sect_strs, key),
                    };
                    layr.keys.push(bkey);
                });
                layr.rows.push(brow);
            });
            layr.layers.push(layer);
        });
    });
    layr.layerCount = layr.layers.length;
    layr.rowCount = layr.rows.length;
    layr.keyCount = layr.keys.length;
    const offset = constants.length_layr +
        (constants.length_layr_list * layr.listCount) +
        (constants.length_layr_entry * layr.layerCount) +
        (constants.length_layr_row * layr.rowCount) +
        (constants.length_layr_key * layr.keyCount);
    layr.size = offset;
    return layr;
}
//# sourceMappingURL=build-layr.js.map