import { constants } from "@keymanapp/ldml-keyboard-constants";
import { build_elem_index } from "./build-elem.js";
import { build_strs_index } from "./build-strs.js";
;
;
;
;
/**
* Builder for the 'tran', 'finl', and 'bksp' sections, all of which use the BUILDER_TRAN layout
*/
export function build_tran(source_tran, sect_strs, sect_elem) {
    if (!source_tran?.groups?.length) {
        return null;
    }
    const tran = {
        ident: constants.hex_section_id(source_tran.id),
        size: 0, // need to compute total transforms + reorders
        _offset: 0,
        groupCount: source_tran.groups.length,
        transformCount: 0,
        reorderCount: 0,
        groups: [],
        transforms: [],
        reorders: [],
    };
    for (const group of source_tran.groups) {
        if (group.type === constants.tran_group_type_transform) {
            tran.groups.push({
                type: group.type,
                count: group.transforms.length,
                index: tran.transforms.length, // index of first item
            });
            for (const transform of group.transforms) {
                tran.transforms.push({
                    from: build_strs_index(sect_strs, transform.from),
                    to: build_strs_index(sect_strs, transform.to),
                    mapFrom: build_strs_index(sect_strs, transform.mapFrom),
                    mapTo: build_strs_index(sect_strs, transform.mapTo),
                });
            }
        }
        else if (group.type === constants.tran_group_type_reorder) {
            tran.groups.push({
                type: group.type,
                count: group.reorders.length,
                index: tran.reorders.length, // index of first item
            });
            for (const reorder of group.reorders) {
                tran.reorders.push({
                    elements: build_elem_index(sect_elem, reorder.elements),
                    before: build_elem_index(sect_elem, reorder.before),
                });
            }
        }
        else {
            throw new Error(`Internal error: at transformGroup #${tran.groups.length + 1}: Unexpected transformGroup type ${group.type}`);
        }
    }
    // now set the sizes
    tran.transformCount = tran.transforms.length;
    tran.reorderCount = tran.reorders.length;
    tran.size = constants.length_tran +
        (constants.length_tran_group * source_tran.groups.length) +
        (constants.length_tran_transform * tran.transforms.length) +
        (constants.length_tran_reorder * tran.reorders.length);
    return tran;
}
//# sourceMappingURL=build-tran.js.map