import { constants } from "@keymanapp/ldml-keyboard-constants";
import { build_strs_index } from "./build-strs.js";
import { build_list_index } from "./build-list.js";
import { build_elem_index } from "./build-elem.js";
;
;
/**
* Builder for the 'vars' section
*/
export function build_vars(kmxplus, sect_strs, sect_elem, sect_list) {
    if (!kmxplus.vars) {
        return null;
    }
    const stringVars = kmxplus.vars.strings.map(v => ({
        type: constants.vars_entry_type_string,
        id: build_strs_index(sect_strs, v.id),
        value: build_strs_index(sect_strs, v.value),
    }));
    const setVars = kmxplus.vars.sets.map(v => ({
        type: constants.vars_entry_type_set,
        id: build_strs_index(sect_strs, v.id),
        value: build_strs_index(sect_strs, v.value),
        elem: build_elem_index(sect_elem, v.items),
    }));
    const uniSetVars = kmxplus.vars.usets.map(v => ({
        type: constants.vars_entry_type_unicodeSet,
        id: build_strs_index(sect_strs, v.id),
        value: build_strs_index(sect_strs, v.value),
    }));
    const vars = {
        ident: constants.hex_section_id(constants.section.vars),
        size: constants.length_vars +
            (constants.length_vars_item * kmxplus.vars.totalCount()),
        _offset: 0,
        markers: build_list_index(sect_list, kmxplus.vars.markers),
        varCount: kmxplus.vars.totalCount(),
        varEntries: [
            ...stringVars,
            ...setVars,
            ...uniSetVars,
        ],
    };
    // sort IDs by binary order
    vars.varEntries.sort((a, b) => a.id - b.id);
    return vars;
}
//# sourceMappingURL=build-vars.js.map