import { CompilerCallbacks } from "../../compiler-callbacks.js";
import { LDMLKeyboardXMLSourceFile } from './ldml-keyboard-xml.js';
import { LDMLKeyboardTestDataXMLSourceFile } from './ldml-keyboard-testdata-xml.js';
interface NameAndProps {
    '$'?: any;
    '#name'?: string;
    '$$'?: any;
}
export declare class LDMLKeyboardXMLSourceFileReaderOptions {
    /** path to the CLDR imports */
    cldrImportsPath: string;
    /** ordered list of paths for local imports */
    localImportsPaths: string[];
}
export declare class LDMLKeyboardXMLSourceFileReader {
    private options;
    private callbacks;
    constructor(options: LDMLKeyboardXMLSourceFileReaderOptions, callbacks: CompilerCallbacks);
    static get defaultImportsURL(): [string, string];
    readImportFile(version: string, subpath: string): Uint8Array;
    readLocalImportFile(path: string): Uint8Array;
    /**
     * xml2js will not place single-entry objects into arrays.
     * Easiest way to fix this is to box them ourselves as needed
     * @param source any
     * @returns true on success, false on failure
     */
    private boxArrays;
    /**
     * Recurse over object, boxing up any specials or imports
     * @param obj any object to be traversed
     * @param subtag the leafmost enclosing tag such as 'keyboard3'
     * @returns true on success, false on failure
     */
    private boxImportsAndSpecials;
    /**
     *
     * @param obj object to be imported into
     * @param subtag obj's element tag, e.g. `keys`
     * @returns true on success, false on failure
     */
    private resolveImports;
    /**
     * @param obj the object being imported into
     * @param subtag obj's element tag, e.g. `keys`
     * @param asImport the import structure
     * @param implied true if it is an implied import
     * @returns true on success, false on failure
     */
    private resolveOneImport;
    /**
     * @returns true if valid, false if invalid
     */
    validate(source: LDMLKeyboardXMLSourceFile | LDMLKeyboardTestDataXMLSourceFile): boolean;
    loadUnboxed(file: Uint8Array): LDMLKeyboardXMLSourceFile;
    /**
     * @param file
     * @returns source on success, otherwise null
     */
    load(file: Uint8Array): LDMLKeyboardXMLSourceFile | null;
    loadTestDataUnboxed(file: Uint8Array): any;
    /**
     * Filter the obj array for a subtag
     * @param source array of source objs
     * @param subtag subtag to filter on
     * @returns
     */
    findSubtagArray(source: NameAndProps[], subtag: string): NameAndProps[];
    /**
     * Get exactly one element
     * @param source
     * @param subtag
     * @returns
     */
    findSubtag(source: NameAndProps[], subtag: string): NameAndProps | null;
    /**
     * The default test data stuffer.
     * Just gets $ (the attrs) as the body.
     * Override to use something more complex, such as including child nodes.
     * @param o object to map
     * @param r back ref to reader
     */
    static readonly defaultMapper: (o: NameAndProps, r: LDMLKeyboardXMLSourceFileReader) => any;
    /**
     *
     * @param obj target object
     * @param source array of $/#name strings
     * @param subtag name to extract
     * @param mapper custom mapper function
     */
    stuffBoxes(obj: any, source: NameAndProps[], subtag: string, asArray?: boolean, mapper?: (v: NameAndProps, r: LDMLKeyboardXMLSourceFileReader) => any): void;
    boxTestDataArrays(raw: any): LDMLKeyboardTestDataXMLSourceFile | null;
    /**
     * @param file test file
     * @returns source on success, otherwise null
     */
    loadTestData(file: Uint8Array): LDMLKeyboardTestDataXMLSourceFile | null;
}
export {};
//# sourceMappingURL=ldml-keyboard-xml-reader.d.ts.map