/*
 * Keyman is copyright (C) SIL Global. MIT License.
 *
 * URL-style path manipulation functions (OS-independent)
 */
import path from 'path-browserify';
/**
 * Helper to replace all backslashes with forward slashes,
 * before passing to posix path module
 */
export class UrlSubpathCompilerCallback {
    normalizeSlashes(path) {
        return path.replaceAll(/\\/g, '/');
    }
    dirname(name) {
        return path.dirname(this.normalizeSlashes(name));
    }
    extname(name) {
        return path.extname(this.normalizeSlashes(name));
    }
    basename(name, ext) {
        return path.basename(this.normalizeSlashes(name), ext);
    }
    isAbsolute(name) {
        return path.isAbsolute(this.normalizeSlashes(name));
    }
    join(...paths) {
        return path.join(...paths.map(this.normalizeSlashes));
    }
    normalize(p) {
        return path.normalize(this.normalizeSlashes(p));
    }
    relative(from, to) {
        return path.relative(this.normalizeSlashes(from), this.normalizeSlashes(to));
    }
    resolve(...args) {
        return path.resolve(...args.map(this.normalizeSlashes));
    }
}
//# sourceMappingURL=UrlSubpathCompilerCallback.js.map