/// <reference types="node" resolution-mode="require"/>
import 'mocha';
import { CompilerEvent } from '../../src/compiler-interfaces.js';
import { LDMLKeyboardXMLSourceFile } from '../../src/types/ldml-keyboard/ldml-keyboard-xml.js';
import { LDMLKeyboardTestDataXMLSourceFile } from '../../src/types/ldml-keyboard/ldml-keyboard-testdata-xml.js';
import { TestCompilerCallbacks } from '@keymanapp/developer-test-helpers';
export interface CompilationCase {
    /**
     * If true, loading (validation) should fail
     */
    loadfail?: boolean;
    /**
     * path to xml, such as 'sections/layr/invalid-case.xml'
     */
    subpath: string;
    /**
     * expected error messages. If falsy, expected to succeed. All must be present to pass.
     */
    errors?: CompilerEvent[];
    /**
     * expected warning messages. All must be present to pass.
     */
    warnings?: CompilerEvent[];
    /**
     * optional callback with the section
     */
    callback?: (data: Buffer, source: LDMLKeyboardXMLSourceFile, subpath: string, callbacks: TestCompilerCallbacks) => void;
    /**
     * if present, expect compiler to throw (use .* to match all)
     */
    throws?: RegExp;
}
export interface TestDataCase {
    /**
     * If true, loading (validation) should fail
     */
    loadfail?: boolean;
    /**
     * path to xml, such as 'sections/layr/invalid-case.xml'
     */
    subpath: string;
    /**
     * expected error messages. If falsy, expected to succeed. All must be present to pass.
     */
    errors?: CompilerEvent[];
    /**
     * expected warning messages. All must be present to pass.
     */
    warnings?: CompilerEvent[];
    /**
     * optional callback with the section
     */
    callback?: (data: Buffer, source: LDMLKeyboardTestDataXMLSourceFile, subpath: string, callbacks: TestCompilerCallbacks) => void;
    /**
     * if present, expect compiler to throw (use .* to match all)
     */
    throws?: RegExp;
}
/**
 * Run a bunch of cases
 * @param cases cases to run
 * @param compiler argument to loadSectionFixture()
 * @param callbacks argument to loadSectionFixture()
 */
export declare function testReaderCases(cases: CompilationCase[]): void;
/**
 * Run a bunch of cases
 * @param cases cases to run
 * @param compiler argument to loadSectionFixture()
 * @param callbacks argument to loadSectionFixture()
 */
export declare function testTestdataReaderCases(cases: TestDataCase[]): void;
//# sourceMappingURL=reader-callback-test.d.ts.map